--- src/SWIG_files/wrapper/Approx.pyi.orig	2026-08-04 19:52:44 UTC
+++ src/SWIG_files/wrapper/Approx.pyi
@@ -100,6 +100,7 @@ Approx_NoApproximation = Approx_Status.Approx_NoApprox
 Approx_NoPointsAdded = Approx_Status.Approx_NoPointsAdded
 Approx_NoApproximation = Approx_Status.Approx_NoApproximation
 
+"""
 class Approx_BSplineApproxInterp:
     def __init__(self, thePoints: TColgp_Array1OfPnt, theNbControlPts: int, theDegree: Optional[int] = 3, theContinuousIfClosed: Optional[bool] = false) -> None: ...
     def Curve(self) -> Geom_BSplineCurve: ...
@@ -120,6 +121,7 @@ class Approx_BSplineApproxInterp:
     def SetMinPivot(self, theMinPivot: float) -> None: ...
     def SetParametrizationAlpha(self, theAlpha: float) -> None: ...
     def SetProjectionTolerance(self, theTol: float) -> None: ...
+""" 
 
 class Approx_Curve2d:
     def __init__(self, C2D: Adaptor2d_Curve2d, First: float, Last: float, TolU: float, TolV: float, Continuity: GeomAbs_Shape, MaxDegree: int, MaxSegments: int) -> None: ...
