--- src/SWIG_files/headers/Approx_module.hxx.orig	2026-08-04 19:50:29 UTC
+++ src/SWIG_files/headers/Approx_module.hxx
@@ -21,7 +21,8 @@ along with pythonOCC.  If not, see <http://www.gnu.org
 
 #include<Approx_Array1OfAdHSurface.hxx>
 #include<Approx_Array1OfGTrsf2d.hxx>
-#include<Approx_BSplineApproxInterp.hxx>
+// Approx_BSplineApproxInterp.hxx is removed
+// #include<Approx_BSplineApproxInterp.hxx>
 #include<Approx_Curve2d.hxx>
 #include<Approx_Curve3d.hxx>
 #include<Approx_CurveOnSurface.hxx>
