--- LPC/CPP.cpp.orig	2026-08-25 13:39:11 UTC
+++ LPC/CPP.cpp
@@ -60,15 +60,15 @@ double CPP_getMean (CPP me, double tmin, double tmax) 
 */
 
 double CPP_getMean (CPP me, double tmin, double tmax) {
-	
+return 0.;	
 }
 
 double CPP_getStandardDeviation (CPP me, double tmin, double tmax) {
-	
+return 0.;	
 }
 
 double CPP_getQuantile (CPP me, double quantile) {
-	
+return 0.;	
 }
 
 autoMatrix CPP_to_Matrix (CPP me) {
