--- src/Mod/Part/App/FCBRepAlgoAPI_BooleanOperation.h.orig	2026-07-01 20:30:17 UTC
+++ src/Mod/Part/App/FCBRepAlgoAPI_BooleanOperation.h
@@ -31,6 +31,7 @@
 
 #include <BRepAlgoAPI_BooleanOperation.hxx>
 #include <Message_ProgressRange.hxx>
+#include <TopTools_ListOfShape.hxx>
 
 class FCBRepAlgoAPIHelper
 {
