--- src/3rdParty/salomesmesh/src/StdMeshers/StdMeshers_Projection_1D.cpp.orig	2026-07-01 15:13:02 UTC
+++ src/3rdParty/salomesmesh/src/StdMeshers/StdMeshers_Projection_1D.cpp
@@ -48,7 +48,6 @@
 #include <TopExp.hxx>
 #include <TopoDS.hxx>
 #include <gp_Pnt.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 #include "utilities.h"
 
