--- src/Mod/Import/App/ImportOCAF2.cpp.orig	2026-07-02 13:42:30 UTC
+++ src/Mod/Import/App/ImportOCAF2.cpp
@@ -38,6 +38,7 @@
 #include <XCAFDoc_DocumentTool.hxx>
 #include <XCAFDoc_GraphNode.hxx>
 #include <XCAFDoc_ShapeTool.hxx>
+#include <TopTools_IndexedMapOfShape.hxx>
 
 
 #include <boost/algorithm/string.hpp>
