--- src/Mod/TechDraw/App/DrawComplexSection.cpp.orig	2026-07-02 14:27:52 UTC
+++ src/Mod/TechDraw/App/DrawComplexSection.cpp
@@ -84,6 +84,7 @@
 #include <ShapeExtend_WireData.hxx>
 #include <TopExp.hxx>
 #include <TopExp_Explorer.hxx>
+#include <TopTools_IndexedMapOfShape.hxx>
 #include <TopoDS.hxx>
 #include <TopoDS_Compound.hxx>
 #include <TopoDS_Edge.hxx>
