--- src/Mod/Import/App/StepShape.cpp.orig	2026-07-02 13:42:30 UTC
+++ src/Mod/Import/App/StepShape.cpp
@@ -34,6 +34,7 @@
 #include <STEPControl_Reader.hxx>
 #include <Standard_Version.hxx>
 #include <StepData_StepModel.hxx>
+#include <TColStd_HSequenceOfTransient.hxx>
 
 #include "StepShape.h"
 
