--- src/Mod/Part/App/BRepOffsetAPI_MakePipeShellPyImp.cpp.orig	2026-07-01 20:50:53 UTC
+++ src/Mod/Part/App/BRepOffsetAPI_MakePipeShellPyImp.cpp
@@ -30,7 +30,6 @@
 #include <gp_Pnt.hxx>
 #include <Standard_Version.hxx>
 #include <TopoDS.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 
 #include <Base/GeometryPyCXX.h>
