--- src/async/core/AsyncMsg.h.orig	2026-05-23 14:59:55 UTC
+++ src/async/core/AsyncMsg.h
@@ -131,7 +131,7 @@ An example of how to use the AsyncMsg class
 #include <set>
 #include <map>
 #include <limits>
-#include <endian.h>
+#include <sys/endian.h>
 #include <stdint.h>
 
 
