--- mysqlshdk/libs/utils/strformat.h.orig	2026-08-13 22:20:00 UTC
+++ mysqlshdk/libs/utils/strformat.h
@@ -27,6 +27,7 @@
 #define MYSQLSHDK_LIBS_UTILS_STRFORMAT_H_

 #include <cstdint>
+#include <ctime>
 #include <string>
 #include <utility>

