--- src/Mod/Surface/Gui/TaskFillingEdge.cpp.orig	2026-07-02 13:42:30 UTC
+++ src/Mod/Surface/Gui/TaskFillingEdge.cpp
@@ -31,7 +31,6 @@
 #include <TopExp.hxx>
 #include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
 #include <TopTools_IndexedMapOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 
 #include <App/Document.h>
 #include <Base/Tools.h>
