--- src/SWIG_files/wrapper/GeomFill.pyi.orig	2026-08-04 19:52:44 UTC
+++ src/SWIG_files/wrapper/GeomFill.pyi
@@ -397,6 +397,7 @@ class GeomFill_Gordon:
     def SetParallelMode(self, theToUseParallel: bool) -> None: ...
     def Surface(self) -> Geom_BSplineSurface: ...
 
+"""
 class GeomFill_GordonBuilder:
     def __init__(self) -> None: ...
     def GuideSurface(self) -> Geom_BSplineSurface: ...
@@ -408,6 +409,7 @@ class GeomFill_GordonBuilder:
     def SetParallelMode(self, theToUseParallel: bool) -> None: ...
     def Surface(self) -> Geom_BSplineSurface: ...
     def TensorSurface(self) -> Geom_BSplineSurface: ...
+"""
 
 class GeomFill_Line(Standard_Transient):
     @overload
