--- src/3rdParty/salomesmesh/src/StdMeshers/StdMeshers_Propagation.cpp.orig	2026-07-01 15:13:02 UTC
+++ src/3rdParty/salomesmesh/src/StdMeshers/StdMeshers_Propagation.cpp
@@ -36,7 +36,6 @@
 #include "SMESH_subMesh.hxx"
 
 #include <BRepTools_WireExplorer.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 #include <TopoDS.hxx>
 
