--- src/Mod/Part/App/ShapeFix/ShapeFix_FacePyImp.cpp.orig	2026-07-01 20:50:53 UTC
+++ src/Mod/Part/App/ShapeFix/ShapeFix_FacePyImp.cpp
@@ -24,6 +24,7 @@
 
 #include <Mod/Part/PartGlobal.h>
 
+#include <TopTools_SequenceOfShape.hxx>
 #include <TopoDS.hxx>
 
 
