--- src/Mod/Part/App/BRepOffsetAPI_MakeOffsetFix.cpp.orig	2026-07-01 20:50:53 UTC
+++ src/Mod/Part/App/BRepOffsetAPI_MakeOffsetFix.cpp
@@ -37,7 +37,6 @@
 #include <TopoDS_Compound.hxx>
 #include <TopoDS_Edge.hxx>
 #include <TopoDS_Wire.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
 #include <TopTools_ListOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 
