--- src/Mod/Import/App/ImportOCAF2.h.orig	2026-07-02 13:09:26 UTC
+++ src/Mod/Import/App/ImportOCAF2.h
@@ -35,6 +35,7 @@
 #include <TopoDS_Shape.hxx>
 #include <XCAFDoc_ColorTool.hxx>
 #include <XCAFDoc_ShapeTool.hxx>
+#include <TDF_LabelSequence.hxx>
 
 #include <Base/Sequencer.h>
 #include <Mod/Part/App/TopoShape.h>
