--- stellarsolver/parameters.h.orig	2026-06-24 17:39:22 UTC
+++ stellarsolver/parameters.h
@@ -33,6 +33,7 @@ typedef enum
 {
     LINUX_DEFAULT,
     LINUX_INTERNAL,
+    FREEBSD_DEFAULT,
     MAC_HOMEBREW,
     WIN_ANSVR,
     WIN_CYGWIN
