--- src/Mod/TechDraw/App/ShapeUtils.cpp.orig	2026-07-02 14:27:52 UTC
+++ src/Mod/TechDraw/App/ShapeUtils.cpp
@@ -32,7 +32,6 @@
 #include <BRepBuilderAPI_MakeFace.hxx>
 #include <BRepBuilderAPI_Transform.hxx>
 #include <BRepLProp_CLProps.hxx>
-#include <BRepLProp_CurveTool.hxx>
 #include <BRepLib.hxx>
 #include <BRepMesh_IncrementalMesh.hxx>
 #include <BRepTools.hxx>
